==> antlrworks-1.1.7-src.zip: src/xj/org/antlr/xjlib/appkit/app/XJApplicationInterface.java <==
/*

[The "BSD licence"]
Copyright (c) 2005 Jean Bovet
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions
are met:

1. Redistributions of source code must retain the above copyright
notice, this list of conditions and the following disclaimer.
2. Redistributions in binary form must reproduce the above copyright
notice, this list of conditions and the following disclaimer in the
documentation and/or other materials provided with the distribution.
3. The name of the author may not be used to endorse or promote products
derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

*/

package org.antlr.xjlib.appkit.app;

import org.antlr.xjlib.appkit.document.XJDocument;
import org.antlr.xjlib.appkit.frame.XJWindow;

import java.util.List;

public interface XJApplicationInterface {

    String getApplicationName();

    XJPreferences getPreferences();

    boolean openDocument();
    boolean openDocuments(List<String> files);
    boolean openDocument(String file);
    boolean openLastUsedDocument();

    XJDocument newDocumentOfData(Class dataClass);
    XJDocument newDocument();
    void addDocument(XJDocument document);
    void removeDocument(XJDocument document);

    XJDocument getActiveDocument();
    XJDocument getDocumentForPath(String path);
    List getDocumentExtensions();
    List<XJDocument> getDocuments();

    void addWindow(XJWindow window);
    void removeWindow(XJWindow window);

    XJWindow getActiveWindow();
    List<XJWindow> getWindows();
    List<XJWindow> getWindowsInWindowMenu();

    boolean supportsPersistence();

    boolean hasPreferencesMenuItem();
    boolean useDesktopMode();

    void addRecentFile(String path);
    void removeRecentFile(String file);
    void clearRecentFiles();
    List recentFiles();

    void performQuit();

    void displayPrefs();
    void displayAbout();
    void displayHelp();
}

==> antlrworks-1.2.2-src.zip: src/xj/org/antlr/xjlib/appkit/app/XJApplicationInterface.java <==
/*

[The "BSD licence"]
Copyright (c) 2005 Jean Bovet
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions
are met:

1. Redistributions of source code must retain the above copyright
notice, this list of conditions and the following disclaimer.
2. Redistributions in binary form must reproduce the above copyright
notice, this list of conditions and the following disclaimer in the
documentation and/or other materials provided with the distribution.
3. The name of the author may not be used to endorse or promote products
derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

*/

package org.antlr.xjlib.appkit.app;

import org.antlr.xjlib.appkit.document.XJDocument;
import org.antlr.xjlib.appkit.frame.XJWindow;

import java.util.List;

public interface XJApplicationInterface {

    String getApplicationName();

    XJPreferences getPreferences();

    boolean openDocument();
    boolean openDocuments(List<String> files);
    boolean openDocument(String file);
    boolean openLastUsedDocument();

    XJDocument newDocument();
    XJWindow getWindowContainingDocumentForPath(String path);
    List getDocumentExtensions();

    void addWindow(XJWindow window);
    void removeWindow(XJWindow window);

    XJWindow getActiveWindow();
    List<XJWindow> getWindows();
    List<XJWindow> getWindowsInWindowMenu();

    boolean supportsPersistence();

    boolean hasPreferencesMenuItem();
    boolean useDesktopMode();

    void addRecentFile(String path);
    void removeRecentFile(String file);
    void clearRecentFiles();
    List recentFiles();

    void performQuit();

    void displayPrefs();
    void displayAbout();
    void displayHelp();
}
